@@ -7,7 +7,8 @@
 #' @title Asymmetric Kiener Distribution K3
 #'
 #' @description
-#' Density, distribution function, quantile function, random generation
+#' Density, distribution function, quantile function, random generation,
+#' value-at-risk, expected shortfall (+ signed left/right tail mean) 
 #' and additional formulae for asymmetric Kiener distribution K3.
 #'
 #' @param    x    vector of quantiles.
@@ -23,6 +24,10 @@
 #' @param    log           logical. If TRUE, densities are given in log scale.
 #' @param    lower.tail    logical. If TRUE, use p. If FALSE, use 1-p.
 #' @param    log.p         logical. If TRUE, probabilities p are given as log(p).
+#' @param    signedES      logical. FALSE (default) returns positive numbers for 
+#'                         left and right tails. TRUE returns negative number 
+#'                         (= \code{ltmkiener3}) for left tail and positive number 
+#'                         (= \code{rtmkiener3}) for right tail.
 #'
 #' @details
 #' Kiener distributions use the following parameters, some of them being redundant. 
@@ -169,8 +174,8 @@
 #' 
 #' @seealso 
 #' Symmetric Kiener distribution K1 \code{\link{kiener1}}, 
-#' asymmetric Kiener distributions K2 and K4  
-#' \code{\link{kiener2}}, \code{\link{kiener4}}, 
+#' asymmetric Kiener distributions K2, K4 and K7
+#' \code{\link{kiener2}}, \code{\link{kiener4}}, \code{\link{kiener7}}, 
 #' conversion functions \code{\link{aw2k}},  
 #' estimation function \code{\link{fitkienerX}}, 
 #' regression function \code{\link{regkienerLX}}.
@@ -472,14 +477,20 @@ return(dtmq)
 #' @export
 #' @rdname kiener3
 eskiener3 <- function(p, m = 0, g = 1, k = 3.2, d = 0, 
-                      lower.tail = TRUE, log.p = FALSE) {
+                      lower.tail = TRUE, log.p = FALSE, signedES = FALSE) {
 	p   <- if(log.p) {exp(p)} else {p}
 	p   <- if(lower.tail) {p} else {1-p}
 	es  <- p
 	for (i in seq_along(p)) {
-		es[i] <- ifelse(p[i] <= 0.5, 
-					- ltmkiener3(p[i], m, g, k, d),
+		if (signedES) {
+			es[i] <- ifelse(p[i] <= 0.5, 
+					  ltmkiener3(p[i], m, g, k, d),
 					  rtmkiener3(p[i], m, g, k, d))
+		} else {
+			es[i] <- ifelse(p[i] <= 0.5, 
+				      abs(ltmkiener3(p[i], m, g, k, d)),
+					  abs(rtmkiener3(p[i], m, g, k, d)))		
+		}
 	}
 return(es)
 }
